=============
Compatibility
=============

Python interpreters
===================

The program is tested against 4 different versions : 3.7, 3.8, 3.9 and 3.10.
The program should work on these, in case of any errors please open an `issue on github <https://github.com/Sydiepus/Manrododex/issues/new>`_.

|NotTested|
===========

I haven't tested it on |NotTested| yet, please report any issues.
Even though i haven't used any platform specific functions/libraries bugs are to be expected.

Linux
=====

This is the platform that the program was developed on, it works nicely i suppose.
Again Bugs are to be expected.

IOS
===

Tested on `iSH Shell <https://ish.app>`_.
The progress bar is broken, i'll try to add an options to disable it and to disable the chapter archiving to make reading the chapters easier.

.. |NotTested| replace:: Windows/Mac OS/Android